
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.28.6',
    'branch_nick': 'release-1.28',
    'revision_id': '0d39d814c9f63e8e8df038977b20356154d7a27f',
    'revno': 11620
}
